@@ -3,7 +3,7 @@ BEGIN {
   $App::Presto::Client::AUTHORITY = 'cpan:BPHILLIPS';
 }
 {
-  $App::Presto::Client::VERSION = '0.008';
+  $App::Presto::Client::VERSION = '0.009';
 }
 
 # ABSTRACT: The REST client
@@ -78,10 +78,8 @@ sub HEAD {
 
 sub DELETE {
 	my $self = shift;
-	my $uri  = $self->_make_uri(@_);
-	my $existing_content_type = $self->clear_header('content-type'); # DELETE shouldn't have a content type
-	my $response = $self->_rest_client->DELETE($uri);
-	$self->set_header('content-type', $existing_content_type) if $existing_content_type;
+	my $uri  = $self->_make_uri(shift);
+	my $response = $self->_rest_client->request('DELETE',$uri, shift);
 	return $response;
 }
 
@@ -164,7 +162,7 @@ App::Presto::Client - The REST client
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 AUTHOR
 
