@@ -3,7 +3,7 @@ BEGIN {
   $App::Presto::Command::HTTP::AUTHORITY = 'cpan:BPHILLIPS';
 }
 {
-  $App::Presto::Command::HTTP::VERSION = '0.008';
+  $App::Presto::Command::HTTP::VERSION = '0.009';
 }
 
 # ABSTRACT: HTTP-related commands
@@ -76,7 +76,7 @@ sub handle_response {
     my $response = $client->response;
     my $config = $self->config;
     if ( $config->get('verbose') ) {
-        print _dump_request_response( $response->request, $response );
+        _dump_request_response( $response->request, $response );
     }
     if ( $client->has_response_content ) {
         if($output_to){
@@ -98,17 +98,11 @@ sub handle_response {
 
 sub _dump_request_response {
     my($request,$response) = @_;
-    return sprintf(<<'_OUT_', $request->method, $request->uri->path_query, $request->headers->as_string, readable_content($request), $response->protocol, $response->status_line, $response->headers->as_string, readable_content($response));
------ REQUEST  -----
-%s %s
-%s
-%s
------ RESPONSE -----
-%s %s
-%s
-%s
------   END    -----
-_OUT_
+    print "----- REQUEST -----\n";
+    print $request->dump;
+    print "----- RESPONSE -----\n";
+    print $response->dump;
+    print "----- END -----\n";
 }
 
 sub readable_content {
@@ -143,7 +137,7 @@ App::Presto::Command::HTTP - HTTP-related commands
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 AUTHOR
 
